<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Support\Str;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\Empleado;
use Illuminate\Support\Facades\Storage;
use Illuminate\Validation\ValidationException;

class EmpleadoController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $empleados = Empleado::all();

        return view('admin.empleados.index', compact('empleados'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $is_create = true;
        $title = 'Registrar Empleado';
        $empleado = new Empleado();

        return view('admin.empleados.form', compact('empleado', ['is_create', 'title']));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {

        try{

            if($request->filled('empleado_id')) {
                $empleado = Empleado::findOrFail($request->empleado_id);
    
                $validatedData = $request->validate([
                    'nombre' => 'required|max:50',
                    'apellido_paterno' => 'required|max:50',
                    'apellido_materno' => 'nullable|max:50',
                    'fecha_nacimiento' => 'required|date',
                    'sexo' => 'required|in:M,F',
                    'correo' => 'nullable|email|max:100',
                    'telefono' => 'nullable|max:20',
                    'grado_estudiante' => 'nullable|max:50',
                    'departamento' => 'nullable|max:50',
                    'ciudad' => 'nullable|max:50',
                    'direccion' => 'nullable|max:255',
                    'foto' => 'nullable|image|max:2048', // Solo imágenes menores a 2MB
                ]);
        
                if ($request->hasFile('foto')) {
                    if ($empleado->foto) {
                        Storage::delete($empleado->foto);
                    }
                    $file = $request->file('foto');
                    $filename = 'empleado_' . Str::random(10) . '.' . $file->getClientOriginalExtension();
                    $rutaFoto = $file->storeAs('empleados', $filename, 'public');
                    $validatedData['foto'] = $rutaFoto;
                }
        
                $empleado->update($validatedData);

                flash()->addSuccess('Empleado actualizado correctamente.');

            }else {
                // Validar los datos del formulario
                $request->validate([
                    'nombre' => 'required|max:50',
                    'apellido_paterno' => 'required|max:50',
                    'apellido_materno' => 'nullable|max:50',
                    'fecha_nacimiento' => 'required|date',
                    'sexo' => 'required|in:M,F',
                    'correo' => 'required|email|max:100',
                    'telefono' => 'nullable|max:20',
                    'grado_estudiante' => 'nullable|max:50',
                    'departamento' => 'nullable|max:50',
                    'ciudad' => 'nullable|max:50',
                    'direccion' => 'nullable|string',
                    'foto' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048'
                ]);

                // Subir la foto si se proporciona
                $fotoPath = null;
                if ($request->hasFile('foto')) {
                    $file = $request->file('foto');
                    $filename = 'empleado_' . Str::random(10) . '.' . $file->getClientOriginalExtension();
                    $fotoPath = $file->storeAs('empleados', $filename, 'public');
                }

                // Crear el empleado en la base de datos
                Empleado::create([
                    'nombre' => $request->nombre,
                    'apellido_paterno' => $request->apellido_paterno,
                    'apellido_materno' => $request->apellido_materno,
                    'fecha_nacimiento' => $request->fecha_nacimiento,
                    'sexo' => $request->sexo,
                    'correo' => $request->correo,
                    'telefono' => $request->telefono,
                    'grado_estudiante' => $request->grado_estudiante,
                    'departamento' => $request->departamento,
                    'ciudad' => $request->ciudad,
                    'direccion' => $request->direccion,
                    'foto' => $fotoPath
                ]);

                flash()->addSuccess('Empleado creado correctamente.');
            }
                return response()->json(array("success" => true));

        } catch (ValidationException $e) {
            return response()->json(['errors' => $e->errors()], 422);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Empleado $empleado)
    {
        $title = 'Modificar Empleado';
        $is_create = false;
        return view('admin.empleados.form', compact('empleado', ['title' ,'is_create']));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        try {
            $empleado = Empleado::findOrFail($id);
    
            $validatedData = $request->validate([
                'nombre' => 'required|max:50',
                'apellido_paterno' => 'required|max:50',
                'correo' => 'nullable|email|max:100',
                'telefono' => 'nullable|max:20',
                'sexo' => 'required|in:M,F',
            ]);
    
            $empleado->update($validatedData);
    
            return response()->json(['success' => 'Empleado actualizado correctamente', 'empleado' => $empleado]);
    
        } catch (ValidationException $e) {
            return response()->json(['errors' => $e->errors()], 422);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Empleado $empleado)
    {
        $empleado->delete();
    }

    public function ajaxList(Request $request)
    {
        $searchText = $request->input('search');  // Busqueda

        // Paginación de 10
        $limit = $request->input('limit'); 
        $offset = $request->input('offset', 0); 

        $query = Empleado::query()
            ->where('nombre', 'LIKE', '%'.$searchText.'%')
            ->orWhere('apellido_materno', 'LIKE', '%'.$searchText.'%')
            ->orWhere('apellido_paterno', 'LIKE', '%'.$searchText.'%')
            ->orWhere('correo', 'LIKE', '%'.$searchText.'%')
            ->orWhere('telefono', 'LIKE', '%'.$searchText.'%');

        $total = $query->count();
        $empleados = $query->skip($offset)->take($limit)->orderBy('created_at', 'desc')->get();
        $empleados = $empleados->map(function($empleado) {
            
            $empleado->fecha_nacimiento = \Carbon\Carbon::parse($empleado->fecha_nacimiento)->format('d/m/Y');

            return $empleado;
        });

        // Devolver datos como JSON
        return response()->json(array("total" => $total, "rows" => $empleados));
    }
}
