export function formHandler(apiEndpoint) {
    return {
      form: {},
      message: '',
      success: false,
      async submitForm() {
        try {
          const csrfToken = document.querySelector('meta[name="csrf-token"]').getAttribute('content');
          const response = await fetch(apiEndpoint, {
            method: 'POST',
            headers: { 'X-CSRF-TOKEN': csrfToken,'Content-Type': 'application/json' },
            body: JSON.stringify(this.form),
          });
  
          if (!response.ok) {
            
            throw new Error('Error al enviar el formulario.');
          }
  
          const data = await response.json();
          this.message = data.message || 'Formulario enviado exitosamente.';
          this.success = true;

          window.location.reload();
  
          // Resetear formulario
          this.form = {};
        } catch (error) {
          this.message = error.message || 'Ocurrió un error.';
          this.success = false;
        }
      },
    };
  }

  export async function handleFormSubmission(event, formId, successMessageId, errorMessageId) {
    
    const form = document.getElementById(formId);
    const successMessage = document.getElementById(successMessageId);
    const errorMessage = document.getElementById(errorMessageId);

    // Prepare the form data
    const formData = new FormData(form);
    
    // Disable the submit button to prevent multiple submissions
    successMessage.style.display = 'none';
    errorMessage.style.display = 'none';

    try {
        // Send the form data using Fetch API
        const response = await fetch(form.action, {
            method: 'POST',
            headers: {
                'X-CSRF-TOKEN': document.querySelector('meta[name="csrf-token"]').getAttribute('content'),
            },
            body: formData
        });

        const data = await response.json();

        if (data.success) {
            form.reset();
            window.location.reload();

        } else if (response.status === 422) {
          // Muestra los errores de validación
          let messageError = ''
          for (let key in data.errors) {
              let input = document.getElementById(key);
              /*
              if (input) {
                  let errorSpan = document.createElement("span");
                  errorSpan.classList.add("text-danger");
                  errorSpan.textContent = data.errors[key][0];
                  input.parentNode.appendChild(errorSpan);
              }*/
              messageError += data.errors[key][0]+'<br>';
          }
          errorMessage.innerHTML = messageError;
          errorMessage.style.display = 'block';
      }
    } catch (error) {
        errorMessage.innerHTML = 'Error, vuelva a intentarlo';
        errorMessage.style.display = 'block';
    }
}