<?php $__env->startSection('content'); ?>
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<style>
    .dashboard-card {
        border-radius: 10px;
        padding: 20px;
        color: #fff;
        text-align: center;
        box-shadow: 0 4px 8px rgba(0,0,0,0.1);
        margin-bottom: 20px;
    }
    .card-clients { background-color: #4e73df; }
    .card-entries { background-color: #1cc88a; }
    .card-products { background-color: #f6c23e; }
    .card-exits { background-color: #e74a3b; }

    .chart-container { height: 400px; margin-top: 30px; }
    
    /* Estilo para los títulos en el Dashboard */
    h5 {
        font-weight: bold;
    }
    .chart-container {
    background-color: #ffffff; /* Fondo blanco */
    border-radius: 12px; /* Bordes más redondeados */
    padding: 40px; /* Espaciado interno más amplio */
    box-shadow: 0 6px 12px rgba(0, 0, 0, 0.1), 0 2px 4px rgba(0, 0, 0, 0.06); /* Sombra elegante */
    border: 1px solid #e0e0e0; /* Borde sutil */
    transition: transform 0.3s ease, box-shadow 0.3s ease; /* Animaciones suaves */
}

.chart-container:hover {
    transform: translateY(-5px); /* Mover ligeramente hacia arriba al pasar el ratón */
    box-shadow: 0 10px 20px rgba(0, 0, 0, 0.12), 0 4px 6px rgba(0, 0, 0, 0.08); /* Mayor sombra al hacer hover */
}

</style>
<div class="container my-4">
    <div class="row">
        <!-- Bloques de información -->
        
        <div class="col-md-3">
            <div class="dashboard-card card-clients">
                <i class="fas fa-building fa-3x"></i>
                <h5> Clientes</h5>
                <p><?php echo e($count['clients'] ?? 0); ?></p>
            </div>
        </div>
        <div class="col-md-3">
            <div class="dashboard-card card-products">
                <i class="fas fa-boxes fa-3x"></i>
                <h5> Productos</h5>
                <p><?php echo e($count['products'] ?? 0); ?></p>
            </div>
        </div>
        <div class="col-md-3">
            <div class="dashboard-card card-entries">
                <i class="fas fa-arrow-left fa-3x"></i>
                <h5> Entradas</h5>
                <p><?php echo e($count['entries'] ?? 0); ?></p>
            </div>
        </div>
        <div class="col-md-3">
            <div class="dashboard-card card-exits">
                <i class="fa-solid fa-arrow-right fa-3x"></i>
                <h5> Salidas</h5>
                <p><?php echo e($count['exits'] ?? 0); ?></p>
            </div>
        </div>
    </div>
    
    <!-- Gráfico de ventas por día -->
    <div class="row mt-4">
        <div class="col-md-6">
            <div class="my-5">
                <div class="chart-container">
                    <canvas id="topProductsChart"></canvas>
                </div>
            </div>
            
        </div>
        <div class="col-md-6">
            <div class="my-5">
                <div class="chart-container">
                    <canvas id="dailyLineChart"></canvas>
                </div>
            </div>
        </div>
    </div>
    <div class="row mt-2">

        <div class="col-md-6">
            <div class="my-2">
                <div class="chart-container">
                    <canvas id="criticalStockChart"></canvas>
                </div>
            </div>
        </div>
        <div class="col-md-6">
            <div class="my-2">
                <div class="chart-container">
                    <canvas id="profitMarginChart"></canvas>
                </div>
            </div>
            
        </div>
    </div>

    
</div>
<script>
    // Obtener datos desde el servidor
    fetch('<?php echo e(route("admin.index.charts")); ?>')
        .then(response => response.json())
        .then(data => {
            renderHorizontalBarChart(data.products)
            renderLineChart(data.daily)
            renderProfitMarginChart(data.products_margen)
            renderHorizontalBarChartCriticalStock(data.critical_stock)
        });
    
        function renderHorizontalBarChart(topProducts) {
            const ctx = document.getElementById('topProductsChart').getContext('2d');

            // Datos para el gráfico
            const labels = topProducts.map(product => product.product_name); // Nombres de los productos
            const totalEntries = topProducts.map(product => product.total_entries); // Entradas
            const totalExits = topProducts.map(product => product.total_exits); // Salidas

            new Chart(ctx, {
                type: 'bar',
                data: {
                    labels: labels,
                    datasets: [
                        {
                            label: 'Entradas',
                            data: totalEntries,
                            backgroundColor: 'rgba(75, 192, 192, 0.6)', // Color para Entradas
                            borderColor: 'rgba(75, 192, 192, 1)',
                            borderWidth: 1,
                        },
                        {
                            label: 'Salidas',
                            data: totalExits,
                            backgroundColor: 'rgba(255, 99, 132, 0.6)', // Color para Salidas
                            borderColor: 'rgba(255, 99, 132, 1)',
                            borderWidth: 1,
                        },
                    ],
                },
                options: {
                    indexAxis: 'y', // Cambia el gráfico a barras horizontales
                    responsive: true,
                    plugins: {
                        legend: {
                            position: 'top',
                        },
                        title: {
                            display: true,
                            text: 'Productos con Más Movimientos',
                        },
                        tooltip: {
                            callbacks: {
                                label: function (tooltipItem) {
                                    const datasetIndex = tooltipItem.datasetIndex;
                                    const value = tooltipItem.raw;
                                    const label = datasetIndex === 0 ? 'Entradas' : 'Salidas';
                                    return `${label}: ${value}`;
                                },
                            },
                        },
                    },
                    scales: {
                        x: {
                            title: {
                                display: true,
                                text: 'Cantidad Total',
                            },
                            beginAtZero: true,
                        },
                        y: {
                            title: {
                                display: true,
                                text: 'Articulos',
                            },
                        },
                    },
                },
            });
        }

        function renderLineChart(dailyMovements) {
            const ctx = document.getElementById('dailyLineChart').getContext('2d');

            // Datos para el gráfico
            const labels = dailyMovements.map(movement => movement.date); // Fechas
            const entries = dailyMovements.map(movement => movement.total_entries); // Entradas
            const exits = dailyMovements.map(movement => movement.total_exits); // Salidas

            new Chart(ctx, {
                type: 'line',
                data: {
                    labels: labels,
                    datasets: [
                        {
                            label: 'Entradas',
                            data: entries,
                            borderColor: 'rgba(75, 192, 192, 1)',
                            backgroundColor: 'rgba(75, 192, 192, 0.2)',
                            borderWidth: 2,
                            tension: 0.4, // Suaviza la línea
                        },
                        {
                            label: 'Salidas',
                            data: exits,
                            borderColor: 'rgba(255, 99, 132, 1)',
                            backgroundColor: 'rgba(255, 99, 132, 0.2)',
                            borderWidth: 2,
                            tension: 0.4, // Suaviza la línea
                        },
                    ],
                },
                options: {
                    responsive: true,
                    plugins: {
                        filler: {
                            propagate: false,
                        },
                        legend: {
                            position: 'top',
                        },
                        title: {
                            display: true,
                            text: 'Entradas y Salidas por Día',
                        },
                        tooltip: {
                            callbacks: {
                                label: function (tooltipItem) {
                                    return `${tooltipItem.dataset.label}: ${tooltipItem.raw}`;
                                },
                            },
                        },
                    },
                    
        interaction: {
        intersect: false,
        },
                    scales: {
                        x: {
                            title: {
                                display: true,
                                text: 'Fecha',
                            },
                        },
                        y: {
                            title: {
                                display: true,
                                text: 'Cantidad',
                            },
                            beginAtZero: true,
                        },
                    },
                },
            });
        }

        function renderProfitMarginChart(products) {
            const ctx = document.getElementById('profitMarginChart').getContext('2d');

            // Datos para el gráfico
            const labels = products.map(product => product.description); // Nombres de los productos
            const profitMargins = products.map(product => product.margin); // Margen de ganancia (precio - costo)
            const prices = products.map(product => product.price); // Precio de venta
            const costs = products.map(product => product.cost); // Costo

            new Chart(ctx, {
                type: 'bar',
                data: {
                    labels: labels,
                    datasets: [{
                        label: 'Margen de Ganancia',
                        data: profitMargins,
                        backgroundColor: 'rgba(75, 192, 192, 0.6)', // Color de las barras
                        borderColor: 'rgba(75, 192, 192, 1)', // Color del borde
                        borderWidth: 1,
                    }],
                },
                options: {
                    responsive: true,
                    plugins: {
                        legend: {
                            display: false, // Ocultar la leyenda
                        },
                        title: {
                            display: true,
                            text: 'Productos con Mayor Margen de Ganancia',
                        },
                        tooltip: {
                            callbacks: {
                                label: function (tooltipItem) {
                                    const index = tooltipItem.dataIndex; // Índice del producto
                                    const productName = labels[index];
                                    const price = Number(prices[index]);
                                    const cost = Number(costs[index]);
                                    const margin = Number(profitMargins[index]);

                                    return [
                                        `Artículo: ${productName}`,
                                        `Costo: $${cost.toFixed(2)}`,
                                        `Precio de Venta: $${price.toFixed(2)}`,
                                        `Margen de Ganancia: $${margin.toFixed(2)}`,
                                    ];
                                },
                            },
                        },
                    },
                    scales: {
                        x: {
                            title: {
                                display: true,
                                text: 'Productos',
                            },
                        },
                        y: {
                            title: {
                                display: true,
                                text: 'Margen de Ganancia ($)',
                            },
                            beginAtZero: true,
                        },
                    },
                },
            });
        }

        function renderHorizontalBarChartCriticalStock(criticalStock) {
            const ctx = document.getElementById('criticalStockChart').getContext('2d');

            // Datos para el gráfico
            const labels = criticalStock.map(item => item.name); // Nombres de los productos
            const stockValues = criticalStock.map(item => item.stock); // Stock actual
            const minStockValues = criticalStock.map(item => item.min_stock); // Umbral mínimo

            new Chart(ctx, {
                type: 'bar',
                data: {
                    labels: labels,
                    datasets: [
                        {
                            label: 'Stock Actual',
                            data: stockValues,
                            backgroundColor: 'rgba(255, 99, 132, 0.6)', // Color para el stock actual
                            borderColor: 'rgba(255, 99, 132, 1)',
                            borderWidth: 1,
                        },
                        {
                            label: 'Umbral Mínimo',
                            data: minStockValues,
                            backgroundColor: 'rgba(54, 162, 235, 0.6)', // Color para el umbral mínimo
                            borderColor: 'rgba(54, 162, 235, 1)',
                            borderWidth: 1,
                        },
                    ],
                },
                options: {
                    indexAxis: 'y', // Barras horizontales
                    responsive: true,
                    plugins: {
                        legend: {
                            position: 'top',
                        },
                        title: {
                            display: true,
                            text: 'Productos con Stock Crítico',
                        },
                        tooltip: {
                            callbacks: {
                                label: function (tooltipItem) {
                                    return `${tooltipItem.label}: ${tooltipItem.raw} unidades`;
                                },
                            },
                        },
                    },
                    scales: {
                        x: {
                            title: {
                                display: true,
                                text: 'Cantidad (Unidades)',
                            },
                            beginAtZero: true,
                        },
                        y: {
                            title: {
                                display: true,
                                text: 'Productos',
                            },
                        },
                    },
                },
            });
        }
</script>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.master', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/jorge/Escritorio/www/sys-control-inventario/resources/views/admin/index.blade.php ENDPATH**/ ?>